//===================================================================================
// 	main.c
// 	USB CDC Class SPI Writer
//===================================================================================
#include <system.h> 
#include <memory.h>
#include "usb_defs.h" 
#include "serial.h"
#include "spi.h"
#include "iocnt.h"
#include "cdc.h"

//for output debug string to SIO
#define _SDEBUG_
#include "sdebug.h"

//Set clock frequency
#ifdef LOW_SPEED_USB
#pragma CLOCK_FREQ	 24000000
#else
#pragma CLOCK_FREQ	 48000000
#endif

//===================================================================================
//	Configration Data
//===================================================================================
// using a 20 Mhz external crystal
#ifdef LOW_SPEED_USB
//Low Speed Setting(CLK=24MHz)
#pragma DATA   _CONFIG1L, 00110100b  // USBPLL, CPU divide by 4 , PLL divide by 5                                                                                          
#else
//Full Speed Setting(CLK=48MHz)
#pragma DATA   _CONFIG1L, 00100100b  // USBPPL, CPU divide by 2 , PPL divide by 5                                                                                          
#endif
#pragma DATA   _CONFIG1H, 00001111b  // disable oscillator switchover,
// disable failsafe clock monitor, HSPPL                                                                                         
#pragma DATA   _CONFIG2L, 00111111b  // USB voltage regulator enabled,
// brownout set for 2.1 volts, hardware brownout only, PWRT disabled                                                                                       
#pragma DATA   _CONFIG2H, 00011110b  // watchdog timer disabled                                                                                      
#pragma DATA   _CONFIG3H, 10000000b  // MCLR enabled                                                                                          
#pragma DATA   _CONFIG4L, 10000001b  // DEBUG off, disable extended instructons, 
// LVP disabled, enable stack full/underflow reset                                                                                        
#pragma DATA   _CONFIG5L, 00001111b  // Read Code protection off                                                                                         
#pragma DATA   _CONFIG5H, 11000000b  // Read EEPROM and boot block protection off                                                                                          
#pragma DATA   _CONFIG6L, 00001111b  // Write Code protection off                                                                                          
#pragma DATA   _CONFIG6H, 11100000b  // Write EEPROM, boot block and
// config register protection off                                                                                                           
#pragma DATA   _CONFIG7L, 00001111b  // Table read protection off                                                                                           
#pragma DATA   _CONFIG7H, 01000000b  // Boot block table read protection off
//===================================================================================
unsigned char oCtrlLineBmp;	// bit 0=DTR,Bit 1=RTS
unsigned char oLineCoding[7];

////////////////////////////////////////////////////////////////
// Interrupt service routine. Branch off to different interrupts
////////////////////////////////////////////////////////////////	
void interrupt (void)
{
	portb=0; //clear indicator leds
	if (bUSBIE && bUSBIF) {
		if (bACTIVITY && bACTIVITY_E) 			// WAS IT AN ACTIVITY WAKEUP?
			USBActivity ();
		if (bUSBRST && bUSBRST_E)				// USB reset must be serviced immediately
			USBReset();
		while(bTOK_DONE && bTOK_DONE_E) {	 		// WAS IT A TOKEN DONE 
			if (USB_dev_req == SET_ADDRESS) { 	// Finish Set Address
				USB_dev_req = NULL;
				USB_Curr_Config = 0;
				uaddr = USB_address_pending;
				uie = 00000101b;
				if (USB_address_pending > 0) {
					USWSTAT= ADDRESS_STATE;
				} else {
					USWSTAT= DEFAULT_STATE;
				}
			}
			bTOK_DONE=0; 						// clear Token Done flag
		}
		bUSBIF=0;								// Clear USB interrupt flag
	}
}

//*****************************************************
//  MAIN PROGRAM
//*****************************************************
void PortInit()
{
	//Port Setting
	porta=0x1e;
	lata = 0x1E;
	portb=0x80;
	portc=0x46;
	portd=0x00;
	porte=0x06;
	trisa = 0x21;
	trisb = 0x6d;
	trisc = 0x30;
	trisd = 0x00;
	trise = 0x00;
	adcon0 = 1;			// Enable A/D ch0
	adcon1 = 0x0e;		// RA0=Analog Input
	adcon2 = 0x3E;
	cmcon = 0x07;  
}
void main() 
{

	PortInit();
	serialInit(38);		// 38=38400pbs(24Mhz),SoftEmulation=9600bps
	SpiInit();			// see spi.c
	dputs("USB Test V1.01"); 
	InitUSB ();
	//main loop
	while (1) {
		UsbInt();
	}
}
